@@ -10,7 +10,7 @@ use std::path::Path;
 
 use anyhow::{Error, Result};
 
-use strum_macros::{Display, EnumIter, EnumMessage, EnumString, IntoStaticStr};
+use strum::{Display, EnumIter, EnumString, IntoStaticStr};
 
 use crate::build::{CInclArgs, LinkArgsBuilder};
 use crate::cli::NativeCommandArgs;
@@ -21,19 +21,7 @@ pub use dep_cmake::*;
 pub use file_api::Query;
 
 /// An enum for parsing and passing to cmake the standard command-line generators.
-#[derive(
-    Copy,
-    Clone,
-    Debug,
-    Eq,
-    PartialEq,
-    Hash,
-    EnumString,
-    Display,
-    EnumMessage,
-    EnumIter,
-    IntoStaticStr,
-)]
+#[derive(Copy, Clone, Debug, Eq, PartialEq, Hash, EnumString, Display, EnumIter, IntoStaticStr)]
 #[strum(ascii_case_insensitive)]
 pub enum Generator {
     Ninja,
